@@ -74,7 +74,7 @@ def extract_airflow_conf(context):
 
     dag_id = task_instance.dag_id
     task_id = task_instance.task_id
-    execution_date = str(task_instance.execution_date)
+    execution_date = task_instance.execution_date.isoformat()
     try_number = str(task_instance.try_number)
 
     if dag_id and task_id and execution_date:
@@ -181,7 +181,7 @@ def set_dbnd_config_from_airflow_connections():
             priority=ConfigValuePriority.NORMAL,
             source=AIRFLOW_DBND_CONNECTION_SOURCE,
         )
-        logger.info(
+        logger.debug(
             "Databand config was set using {0} connection.".format(
                 DATABAND_AIRFLOW_CONN_ID
             )
